const initialState = {
    statements: [],
    filteredStatements: [],
    loadingStatements: false,
    selectedStatement: null,
    currencyStatement: null,
    showStatement: false,
    /* transfer */
    statementsDest : [],
    filteredStatementDest: [],
    selectedStatementDest: null,
}
const state = {
    statements: initialState.statements,
    filteredStatements: initialState.filteredStatements,
    loadingStatements: initialState.loadingStatements,
    selectedStatement: initialState.selectedStatement,
    currencyStatement: initialState.currencyStatement,
    showStatement: initialState.showStatement,
    /* Transfer */
    statementsDest: initialState.statementsDest,
    filteredStatementDest: initialState.filteredStatementDest,
    selectedStatementDest: initialState.selectedStatementDest
}
const getters = {
    statements(state) {
        return  state.statements
    },
    visibleStatement(state) {
        return  state.filteredStatements.length === 0 ? state.statements :state.filteredStatements;
    },
    loadingStatements(state) {
        return  state.loadingStatements
    },
    filteredStatements(state) {
        return state.filteredStatements;
    },
    selectedStatement(state) {
        return state.selectedStatement
    },
    showStatement(state) {
        return state.showStatement
    },
    currencyStatement(state) {
        return state.currencyStatement
    },
    statementsDest(state){
        return state.statementsDest;
    },
    selectedStatementDest(state) {
        return state.selectedStatementDest
    },
    filteredStatementDest(state) {
        return state.filteredStatementDest
    },
    visibleStatementDest(state) {
        return  state.filteredStatementDest.length === 0 ? state.statementsDest :state.filteredStatementDest;
    },
    amountStatementOrigin(state) {
        return  !state.selectedStatement ? 0 : state.selectedStatement.balanceEnd
    },
    stateStatementSelected(state) {
        return !state.selectedStatement ? "" : state.selectedStatement.state
    },
    getJournalSelectedStatement(state) {
        return !!state.selectedStatement ?state.selectedStatement.journalName  :''
    },
    getTypeSelectedStatement(state) {
        return !!state.selectedStatement ?state.selectedStatement.typeStatementName : ''
    },
    getUserSelectedStatement(state) {
        return !!state.selectedStatement  ?state.selectedStatement.userName :''
    },
}


const mutations = {
    setStatements(state, payload) {
        state.statements = payload
    },
    setLoadingStatements(state, payload) {
        state.loadingStatements = !!payload
    },
    setFilteredStatements(state, payload){
        state.filteredStatements = payload
    },
    setSelectedStatement(state, payload){
        state.selectedStatement = payload
    },
    setShowStatement(state, payload){
        state.showStatement = !!payload
    },
    setSelectedStatementDest(state, payload) {
        state.selectedStatementDest = payload
    },
    setCurrencyStatement(state, payload) {
        if (!payload){
            state.currencyStatement = null
        }
        state.currencyStatement = payload.currency
    },
    setStatementsDest(state, payload) {
        state.statementsDest = state.statements.filter(item => item.id !== state.selectedStatement.id && item.journalId === state.selectedStatement.journalId && item.state === 'open')
    },
    setFilteredStatementsDest(state, payload) {
        state.filteredStatementDest = payload
    },
    addStatment(state, payload) {
        state.statements = [payload, ...state.statements]
    },
}

const actions = {
    initStatement({ commit }, payload) {
        commit('setStatements', payload)
        commit('setLoadingStatements', payload)
    },
    /* Filter */
    filteredStatements( {commit}, payload) {
        commit('setFilteredStatements', payload)
    },
    filteredStatementsDest( {commit}, payload) {
        commit('setFilteredStatementsDest', payload)
    },
    showStatementAdd({ commit }, payload) {
        commit('setShowStatement', payload)
    },
    /* Selected */
    selectedStatements({ dispatch, commit }, payload) {

        commit('setSelectedStatement', payload)
        commit('setCurrencyStatement', payload)
        dispatch('verifyActionCashbox', payload)
    },
    filteredStatementsDest({ commit, getters }){
        commit('setStatementsDest', getters.selectedStatement)
    },
    selectStatementsDest( { commit },payload){
        commit('setSelectedStatementDest', payload)
    },
    /* Resetar */
    resetStatement({ commit }) {
        commit('setStatements', [])
        commit('setLoadingStatements', false)
        commit('setFilteredStatements', [])
        commit('setSelectedStatement', null)

        commit('setStatementsDest')
        commit('setFilteredStatementsDest', [])
        commit('setSelectedStatementDest', null)

        commit('setShowStatement', false)
        // loadingStatements: false,
        // filteredStatements: [],
        // selectedStatement: null,
        // statements: [],
        // currencyStatement: null,
        // showStatement: false,
        /* transfer */
        // statementsDest : [],
        // filteredStatementDest: [],
        // selectedStatementDest: null,
    },
    resetStatemntDest({ commit }) {
        commit('setStatementsDest',[])
        commit('setFilteredStatementsDest', [])
        commit('setSelectedStatementDest', null)
    },
    receiveStatment({ commit }, payload) {
        commit('addStatment', payload)
        commit('setLoadingStatements', false)

    },
}

export default {
    state,
    getters,
    mutations,
    actions
}
