const initialState = {
    lines: [],
    lineSelected: null,
    linesDeleted: [],
    linesUpdate: [],
    showStatementLine: false
}

const state = {
    lines: initialState.lines,
    lineSelected: initialState.lineSelected,
    linesDeleted: initialState.linesDeleted,
    linesUpdate: initialState.linesUpdate,
    showStatementLine: initialState.showStatementLine,
}

const getters = {
    statementLines(state) {
        return state.lines
    },
    linesDeleted(state) {
        return state.linesDeleted
    },
    linesUpdate(state) {
        return state.linesUpdate
    },
    showStatementLine(state) {
        return state.showStatementLine
    },
    lineSelected(state) {
        return  state.lineSelected;
    }
}

const mutations = {
    setLines(state, payload) {
        let data = []
        payload.forEach(item => {
            data.push({
                id: item.id,
                date: item.date,
                name: item.name,
                ref: item.ref,
                amount: item.amount,
                // partner: {
                //     'id': item.partnerId,
                //     'name': item.partnerNane,
                //     'ruc': '',
                //  },
                partnerId: item.partnerId,
                partnerName: item.partnerNane,
                isDelete: false,
                isUpdate: false,
            })
        })
        state.lines = data
    },
    /*Show Modal Modify Line */
    setShowStatementLine( state, payload){
        state.showStatementLine = payload
    },
    /* */
    setLinesDeleted (state, payload) {
        state.lines.forEach(item => {
            if (item.id === payload.id ) {
                item.isDelete = payload.state
            }
        })

        if (!!payload.state) {
            let linesDeletedFound = state.linesDeleted.find(item => item === payload.id)
            if (!!linesDeletedFound) return
            state.linesDeleted = [payload.id, ...state.linesDeleted]
        }

        if (!payload.state) {
            let linesDeletedFound = state.linesDeleted.findIndex(item => item === payload.id)
            state.linesDeleted.splice(linesDeletedFound, 1)
        }
    },
    /* Add Update */
    setLinesUpdate (state, payload) {
        if (!payload) {
            return
        }

        let updateLine =  state.lines.find(item => item.id === payload.id)
        if (updateLine){
            updateLine.amount = payload.amount
            updateLine.date = payload.date
            updateLine.name = payload.name
            updateLine.isUpdate = true
            // updateLine.partner = payload.partner
            updateLine.partnerId = payload.partner.id
            updateLine.partnerName = payload.partner.name
            updateLine.ref = payload.ref
        }

        let linesUpdateFound = state.linesUpdate.find(item => item.id === payload.id)
        if (!!linesUpdateFound) {
            let linesIndex = state.linesUpdate.findIndex(item => item.id === payload.id)
            state.linesUpdate.splice(linesIndex, 1)
        }

        let statementLine = {
            'amount': payload.amount,
            'date': payload.date,
            'id': payload.id,
            'isDelete': payload.isDelete,
            'isUpdate': true,
            'name': payload.name,
            // 'partner': payload.partner,
            'partnerId': payload.partnerId,
            'partnerName': payload.partnerName,
            'ref':payload.ref,
        }

        state.linesUpdate = [statementLine, ...state.linesUpdate]
    },
    /* Selected */
    setLineSelected(state, payload) {
        let selected = state.lines.find(item => item.id  === payload)
        state.lineSelected = !!selected ? selected : null
    },
    /* Reset */
    setResetLines(state){
        state.lines = []
        state.lineSelected = null
        state.linesDeleted = []
        state.linesUpdate = []
        state.showStatementLine = false
    },
}

const actions = {
    initLines({ commit, getters }) {
        if (!!getters.selectedStatement) {
            commit('setLines', getters.selectedStatement.lines)
        }
    },
    selectLineSelected({ commit },payload) {
        commit('setLineSelected', payload)
        commit('setShowStatementLine', payload)
    },
    addDeletedLine({ commit }, payload) {
        commit('setLinesDeleted', payload)
    },
    addUpdateLine({ commit }, payload) {
        commit('setLinesUpdate', payload)
        commit('setShowStatementLine', false)
        commit('setLineSelected', null)
    },
    showStatementLineModify({ commit }, payload) {
        commit('setShowStatementLine', payload)
    },
    resetStatementLine({ commit }) {
        commit('setResetLines')
    }
}

export default{
    state,
    getters,
    mutations,
    actions
}
